@@ -20,13 +20,17 @@ class JAAQLController(BaseJAAQLController):
             return self.model.get_auth_token(**http_inputs, ip_address=ip_address, response=response)
 
         @self.cors_route(ENDPOINT__refresh, DOCUMENTATION__oauth_refresh)
-        def refresh_oauth_token(auth_token: str, ip_address: str):
-            return self.model.refresh_auth_token(auth_token, ip_address)
+        def refresh_oauth_token(auth_token_for_refresh: str, ip_address: str):
+            return self.model.refresh_auth_token(auth_token_for_refresh, ip_address)
 
         @self.cors_route(ENDPOINT__install, DOCUMENTATION__install)
         def install(http_inputs: dict):
             return self.model.install(**http_inputs)
 
+        @self.cors_route(ENDPOINT__execute_migrations, DOCUMENTATION__migrations)
+        def execute_migrations(connection: DBInterface):
+            return self.model.execute_migrations(connection)
+
         @self.cors_route('/internal/is_installed', DOCUMENTATION__is_installed)
         def is_installed(response: JAAQLResponse):
             return self.model.is_installed(response)
@@ -39,9 +43,14 @@ class JAAQLController(BaseJAAQLController):
         def accounts(connection: DBInterface, http_inputs: dict):
             self.model.create_account_with_potential_password(connection, **http_inputs)
 
+        @self.cors_route('/prepare', DOCUMENTATION__prepare)
+        def prepare(connection: DBInterface, account_id: str, http_inputs: dict):
+            raise HttpStatusException("Not yet implemented", HTTPStatus.NOT_IMPLEMENTED)
+            # self.model.prepare_queries(connection, account_id, http_inputs)
+
         @self.cors_route('/account/password', DOCUMENTATION__password)
-        def password(account_id: str, username: str, ip_address: str, http_inputs: dict):
-            return self.model.add_my_account_password(account_id, username, ip_address, **http_inputs)
+        def password(account_id: str, username: str, ip_address: str, is_the_anonymous_user: bool, http_inputs: dict):
+            return self.model.add_my_account_password(account_id, username, ip_address, is_the_anonymous_user, **http_inputs)
 
         @self.cors_route('/submit', DOCUMENTATION__submit)
         def submit(http_inputs: dict, account_id: str, verification_hook: queue.Queue):
@@ -59,6 +68,10 @@ class JAAQLController(BaseJAAQLController):
         def sign_up(http_inputs: dict):
             return self.model.sign_up(http_inputs)
 
+        @self.cors_route('/email', DOCUMENTATION__emails)
+        def send_email(is_the_anonymous_user: bool, account_id: str, inputs: dict):
+            return self.model.send_email(is_the_anonymous_user, account_id, inputs)
+
         @self.cors_route('/account/reset-password', DOCUMENTATION__reset_password)
         def reset_password(http_inputs: dict):
             return self.model.reset_password(http_inputs)
